pub struct ValidIpV6Ext6564<V: ByteSlice>(pub Accessor<V, IpV6Ext6564Part0>, pub HeaderOf<Vec<u8>, V>);Tuple Fields
0: Accessor<V, IpV6Ext6564Part0>1: HeaderOf<Vec<u8>, V>Trait Implementations
Sourceimpl<V: ByteSlice> Emit for ValidIpV6Ext6564<V>
impl<V: ByteSlice> Emit for ValidIpV6Ext6564<V>
Sourcefn emit_raw<B: ByteSliceMut>(&self, buf: B) -> usize
fn emit_raw<B: ByteSliceMut>(&self, buf: B) -> usize
Writes this packet’s contents into a target buffer without
performing length checks. Read more
Sourcefn needs_emit(&self) -> bool
fn needs_emit(&self) -> bool
Returns whether this packet needs a full re-emit, and
has not been simply modified in-place. Read more
Sourcefn emit<V>(&self, buf: V) -> Result<usize, ParseError>where
V: ByteSliceMut,
fn emit<V>(&self, buf: V) -> Result<usize, ParseError>where
V: ByteSliceMut,
Writes this packet’s contents into a target buffer.
Sourcefn emit_prefix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
fn emit_prefix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
Writes this packet’s contents into the start of a target buffer.
Sourcefn emit_suffix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
fn emit_suffix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
Writes this packet’s contents at the end of a target buffer.
Sourcefn emit_uninit(&self, buf: &mut [MaybeUninit<u8>]) -> Result<usize, ParseError>where
Self: EmitDoesNotRelyOnBufContents,
fn emit_uninit(&self, buf: &mut [MaybeUninit<u8>]) -> Result<usize, ParseError>where
Self: EmitDoesNotRelyOnBufContents,
Writes this packet’s contents into uninitialised memory.
Sourcefn emit_vec(&self) -> Vec<u8> ⓘwhere
Self: EmitDoesNotRelyOnBufContents,
fn emit_vec(&self) -> Vec<u8> ⓘwhere
Self: EmitDoesNotRelyOnBufContents,
Writes this packet’s contents into a newly allocated
Vec of length
Header::packet_length, without zero-filling the contents. Read moreimpl<V: ByteSlice> EmitDoesNotRelyOnBufContents for ValidIpV6Ext6564<V>
Sourceimpl<V: ByteSlice> From<&ValidIpV6Ext6564<V>> for IpV6Ext6564
impl<V: ByteSlice> From<&ValidIpV6Ext6564<V>> for IpV6Ext6564
Sourcefn from(val: &ValidIpV6Ext6564<V>) -> Self
fn from(val: &ValidIpV6Ext6564<V>) -> Self
Converts to this type from the input type.
Sourceimpl<V: ByteSlice> From<ValidIpV6Ext6564<V>> for InlineHeader<IpV6Ext6564, ValidIpV6Ext6564<V>>
impl<V: ByteSlice> From<ValidIpV6Ext6564<V>> for InlineHeader<IpV6Ext6564, ValidIpV6Ext6564<V>>
Sourcefn from(value: ValidIpV6Ext6564<V>) -> Self
fn from(value: ValidIpV6Ext6564<V>) -> Self
Converts to this type from the input type.
Sourceimpl<V: ByteSlice> From<ValidIpV6Ext6564<V>> for BoxedHeader<IpV6Ext6564, ValidIpV6Ext6564<V>>
impl<V: ByteSlice> From<ValidIpV6Ext6564<V>> for BoxedHeader<IpV6Ext6564, ValidIpV6Ext6564<V>>
Sourcefn from(value: ValidIpV6Ext6564<V>) -> Self
fn from(value: ValidIpV6Ext6564<V>) -> Self
Converts to this type from the input type.
Sourceimpl<V: ByteSlice> HasRepr for ValidIpV6Ext6564<V>
impl<V: ByteSlice> HasRepr for ValidIpV6Ext6564<V>
Sourcetype ReprType = IpV6Ext6564
type ReprType = IpV6Ext6564
The type containing an equivalent to
Self, as an owned struct.Sourceimpl<V: ByteSlice> HeaderLen for ValidIpV6Ext6564<V>
impl<V: ByteSlice> HeaderLen for ValidIpV6Ext6564<V>
Sourceconst MINIMUM_LENGTH: usize
const MINIMUM_LENGTH: usize
The minimum number of bytes a packet of this kind occupies
when serialised.
Sourcefn packet_length(&self) -> usize
fn packet_length(&self) -> usize
The number of bytes which this packet would occupy when serialised. Read more
Sourceimpl<'a, V: SplitByteSlice + IntoBufPointer<'a> + 'a> HeaderParse<V> for ValidIpV6Ext6564<V>
impl<'a, V: SplitByteSlice + IntoBufPointer<'a> + 'a> HeaderParse<V> for ValidIpV6Ext6564<V>
Sourcefn parse_choice(
from: V,
_hint: Option<Self::Hint>,
) -> ParseResult<Success<Self, V>>
fn parse_choice( from: V, _hint: Option<Self::Hint>, ) -> ParseResult<Success<Self, V>>
Parse a view-type from a given buffer, using a hint
Sourceimpl<V: ByteSliceMut> IpV6Ext6564Mut<V> for ValidIpV6Ext6564<V>
impl<V: ByteSliceMut> IpV6Ext6564Mut<V> for ValidIpV6Ext6564<V>
fn set_next_header(&mut self, val: IpProtocol)
fn next_header_mut(&mut self) -> &mut IpProtocol
fn set_ext_len(&mut self, val: u8)
fn ext_len_mut(&mut self) -> &mut u8
fn data_mut(&mut self) -> FieldMut<'_, Vec<u8>, V>
Sourceimpl<V: ByteSlice> IpV6Ext6564Ref<V> for ValidIpV6Ext6564<V>
impl<V: ByteSlice> IpV6Ext6564Ref<V> for ValidIpV6Ext6564<V>
fn next_header(&self) -> IpProtocol
fn next_header_ref(&self) -> &IpProtocol
fn ext_len(&self) -> u8
fn ext_len_ref(&self) -> &u8
fn data_ref(&self) -> FieldRef<'_, Vec<u8>, V>
Sourceimpl<V: ByteSlice> NextLayer for ValidIpV6Ext6564<V>
impl<V: ByteSlice> NextLayer for ValidIpV6Ext6564<V>
Sourcetype Denom = IpProtocol
type Denom = IpProtocol
The type of this header’s next-layer hint.
Sourcefn next_layer_choice(&self, _hint: Option<Self::Hint>) -> Option<Self::Denom>
fn next_layer_choice(&self, _hint: Option<Self::Hint>) -> Option<Self::Denom>
Try to retrieve this header’s next-layer hint, using a provided hint
Sourcefn next_layer(&self) -> Option<Self::Denom>
fn next_layer(&self) -> Option<Self::Denom>
Retrieve this header’s next-layer hint, if possible.
Sourceimpl<V: SplitByteSlice> ToOwnedPacket for ValidIpV6Ext6564<V>
impl<V: SplitByteSlice> ToOwnedPacket for ValidIpV6Ext6564<V>
Sourceimpl<V: ByteSlice> TryFrom<ValidLowRentV6Eh<V>> for ValidIpV6Ext6564<V>
impl<V: ByteSlice> TryFrom<ValidLowRentV6Eh<V>> for ValidIpV6Ext6564<V>
Sourcetype Error = ParseError
type Error = ParseError
The type returned in the event of a conversion error.