pub struct ValidIpV6ExtFragment<V: ByteSlice>(pub Accessor<V, IpV6ExtFragmentPart0>);Tuple Fields
0: Accessor<V, IpV6ExtFragmentPart0>Trait Implementations
Sourceimpl<V: ByteSlice> Emit for ValidIpV6ExtFragment<V>
impl<V: ByteSlice> Emit for ValidIpV6ExtFragment<V>
Sourcefn emit_raw<B: ByteSliceMut>(&self, buf: B) -> usize
fn emit_raw<B: ByteSliceMut>(&self, buf: B) -> usize
Writes this packet’s contents into a target buffer without
performing length checks. Read more
Sourcefn needs_emit(&self) -> bool
fn needs_emit(&self) -> bool
Returns whether this packet needs a full re-emit, and
has not been simply modified in-place. Read more
Sourcefn emit<V>(&self, buf: V) -> Result<usize, ParseError>where
V: ByteSliceMut,
fn emit<V>(&self, buf: V) -> Result<usize, ParseError>where
V: ByteSliceMut,
Writes this packet’s contents into a target buffer.
Sourcefn emit_prefix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
fn emit_prefix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
Writes this packet’s contents into the start of a target buffer.
Sourcefn emit_suffix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
fn emit_suffix<V>(&self, buf: V) -> Result<V, ParseError>where
V: SplitByteSliceMut,
Writes this packet’s contents at the end of a target buffer.
Sourcefn emit_uninit(&self, buf: &mut [MaybeUninit<u8>]) -> Result<usize, ParseError>where
Self: EmitDoesNotRelyOnBufContents,
fn emit_uninit(&self, buf: &mut [MaybeUninit<u8>]) -> Result<usize, ParseError>where
Self: EmitDoesNotRelyOnBufContents,
Writes this packet’s contents into uninitialised memory.
Sourcefn emit_vec(&self) -> Vec<u8> ⓘwhere
Self: EmitDoesNotRelyOnBufContents,
fn emit_vec(&self) -> Vec<u8> ⓘwhere
Self: EmitDoesNotRelyOnBufContents,
Writes this packet’s contents into a newly allocated
Vec of length
Header::packet_length, without zero-filling the contents. Read moreimpl<V: ByteSlice> EmitDoesNotRelyOnBufContents for ValidIpV6ExtFragment<V>
Sourceimpl<V: ByteSlice> From<&ValidIpV6ExtFragment<V>> for IpV6ExtFragment
impl<V: ByteSlice> From<&ValidIpV6ExtFragment<V>> for IpV6ExtFragment
Sourcefn from(val: &ValidIpV6ExtFragment<V>) -> Self
fn from(val: &ValidIpV6ExtFragment<V>) -> Self
Converts to this type from the input type.
Sourceimpl<V: ByteSlice> From<ValidIpV6ExtFragment<V>> for InlineHeader<IpV6ExtFragment, ValidIpV6ExtFragment<V>>
impl<V: ByteSlice> From<ValidIpV6ExtFragment<V>> for InlineHeader<IpV6ExtFragment, ValidIpV6ExtFragment<V>>
Sourcefn from(value: ValidIpV6ExtFragment<V>) -> Self
fn from(value: ValidIpV6ExtFragment<V>) -> Self
Converts to this type from the input type.
Sourceimpl<V: ByteSlice> From<ValidIpV6ExtFragment<V>> for BoxedHeader<IpV6ExtFragment, ValidIpV6ExtFragment<V>>
impl<V: ByteSlice> From<ValidIpV6ExtFragment<V>> for BoxedHeader<IpV6ExtFragment, ValidIpV6ExtFragment<V>>
Sourcefn from(value: ValidIpV6ExtFragment<V>) -> Self
fn from(value: ValidIpV6ExtFragment<V>) -> Self
Converts to this type from the input type.
Sourceimpl<V: ByteSlice> HasRepr for ValidIpV6ExtFragment<V>
impl<V: ByteSlice> HasRepr for ValidIpV6ExtFragment<V>
Sourcetype ReprType = IpV6ExtFragment
type ReprType = IpV6ExtFragment
The type containing an equivalent to
Self, as an owned struct.Sourceimpl<V: ByteSlice> HeaderLen for ValidIpV6ExtFragment<V>
impl<V: ByteSlice> HeaderLen for ValidIpV6ExtFragment<V>
Sourceconst MINIMUM_LENGTH: usize
const MINIMUM_LENGTH: usize
The minimum number of bytes a packet of this kind occupies
when serialised.
Sourcefn packet_length(&self) -> usize
fn packet_length(&self) -> usize
The number of bytes which this packet would occupy when serialised. Read more
Sourceimpl<'a, V: SplitByteSlice + IntoBufPointer<'a> + 'a> HeaderParse<V> for ValidIpV6ExtFragment<V>
impl<'a, V: SplitByteSlice + IntoBufPointer<'a> + 'a> HeaderParse<V> for ValidIpV6ExtFragment<V>
Sourcefn parse_choice(
from: V,
_hint: Option<Self::Hint>,
) -> ParseResult<Success<Self, V>>
fn parse_choice( from: V, _hint: Option<Self::Hint>, ) -> ParseResult<Success<Self, V>>
Parse a view-type from a given buffer, using a hint
Sourceimpl<V: ByteSliceMut> IpV6ExtFragmentMut for ValidIpV6ExtFragment<V>
impl<V: ByteSliceMut> IpV6ExtFragmentMut for ValidIpV6ExtFragment<V>
fn set_next_header(&mut self, val: IpProtocol)
fn next_header_mut(&mut self) -> &mut IpProtocol
fn set_reserved(&mut self, val: u8)
fn reserved_mut(&mut self) -> &mut u8
fn set_fragment_offset(&mut self, val: u13be)
fn set_res(&mut self, val: u2)
fn set_more_frags(&mut self, val: u1)
fn set_ident(&mut self, val: u32be)
Sourceimpl<V: ByteSlice> IpV6ExtFragmentRef for ValidIpV6ExtFragment<V>
impl<V: ByteSlice> IpV6ExtFragmentRef for ValidIpV6ExtFragment<V>
fn next_header(&self) -> IpProtocol
fn next_header_ref(&self) -> &IpProtocol
fn reserved(&self) -> u8
fn reserved_ref(&self) -> &u8
fn fragment_offset(&self) -> u13be
fn res(&self) -> u2
fn more_frags(&self) -> u1
fn ident(&self) -> u32be
Sourceimpl<V: ByteSlice> NextLayer for ValidIpV6ExtFragment<V>
impl<V: ByteSlice> NextLayer for ValidIpV6ExtFragment<V>
Sourcetype Denom = IpProtocol
type Denom = IpProtocol
The type of this header’s next-layer hint.
Sourcefn next_layer_choice(&self, _hint: Option<Self::Hint>) -> Option<Self::Denom>
fn next_layer_choice(&self, _hint: Option<Self::Hint>) -> Option<Self::Denom>
Try to retrieve this header’s next-layer hint, using a provided hint
Sourcefn next_layer(&self) -> Option<Self::Denom>
fn next_layer(&self) -> Option<Self::Denom>
Retrieve this header’s next-layer hint, if possible.
Sourceimpl<V: SplitByteSlice> ToOwnedPacket for ValidIpV6ExtFragment<V>
impl<V: SplitByteSlice> ToOwnedPacket for ValidIpV6ExtFragment<V>
Sourceimpl<V: ByteSlice> TryFrom<ValidLowRentV6Eh<V>> for ValidIpV6ExtFragment<V>
impl<V: ByteSlice> TryFrom<ValidLowRentV6Eh<V>> for ValidIpV6ExtFragment<V>
Sourcetype Error = ParseError
type Error = ParseError
The type returned in the event of a conversion error.